pub struct AmountInfo {
pub amount: f64,
pub unit: String,
}Fields
amount: f64unit: StringTrait Implementations
Sourceimpl Clone for AmountInfo
impl Clone for AmountInfo
Sourcefn clone(&self) -> AmountInfo
fn clone(&self) -> AmountInfo
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AmountInfo
impl Debug for AmountInfo
Sourceimpl Default for AmountInfo
impl Default for AmountInfo
Sourceimpl<'de> Deserialize<'de> for AmountInfo
impl<'de> Deserialize<'de> for AmountInfo
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AmountInfo
impl JsonSchema for AmountInfo
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for AmountInfo
impl RefUnwindSafe for AmountInfo
impl Send for AmountInfo
impl Sync for AmountInfo
impl Unpin for AmountInfo
impl UnsafeUnpin for AmountInfo
impl UnwindSafe for AmountInfo