pub struct CartView {
pub basket_id: String,
pub store: Store,
pub account: Option<String>,
pub items: Vec<CartItemView>,
pub totals: PriceSummary,
}Fields
basket_id: Stringstore: Storeaccount: Option<String>null when the session is anonymous – the cart is then a throwaway
basket, not the account’s.
items: Vec<CartItemView>totals: PriceSummaryTrait Implementations
Sourceimpl JsonSchema for CartView
impl JsonSchema for CartView
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for CartView
impl RefUnwindSafe for CartView
impl Send for CartView
impl Sync for CartView
impl Unpin for CartView
impl UnsafeUnpin for CartView
impl UnwindSafe for CartView