pub struct PersonalOffer {
pub localized_title: LocalizedName,
pub pricing: Option<PersonalOfferPricing>,
pub normal_pricing: Option<PersonalOfferNormalPricing>,
pub products: Vec<PersonalOfferProduct>,
pub remaining_quantity: Option<u32>,
pub valid_until: Option<String>,
}Fields
localized_title: LocalizedNamepricing: Option<PersonalOfferPricing>normal_pricing: Option<PersonalOfferNormalPricing>products: Vec<PersonalOfferProduct>remaining_quantity: Option<u32>How many redemptions are left on the Plussa card. Distinct from valid_until:
an offer can still have time left but no redemptions, or the reverse.
valid_until: Option<String>Trait Implementations
Sourceimpl Clone for PersonalOffer
impl Clone for PersonalOffer
Sourcefn clone(&self) -> PersonalOffer
fn clone(&self) -> PersonalOffer
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PersonalOffer
impl Debug for PersonalOffer
Sourceimpl<'de> Deserialize<'de> for PersonalOffer
impl<'de> Deserialize<'de> for PersonalOffer
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<PersonalOffer> for PersonalOfferView
impl From<PersonalOffer> for PersonalOfferView
Sourcefn from(o: PersonalOffer) -> Self
fn from(o: PersonalOffer) -> Self
Converts to this type from the input type.