pub struct PriceSummary {
pub items_sub_total: f64,
pub grand_total: f64,
}Fields
items_sub_total: f64grand_total: f64Trait Implementations
Sourceimpl Clone for PriceSummary
impl Clone for PriceSummary
Sourcefn clone(&self) -> PriceSummary
fn clone(&self) -> PriceSummary
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PriceSummary
impl Debug for PriceSummary
Sourceimpl Default for PriceSummary
impl Default for PriceSummary
Sourcefn default() -> PriceSummary
fn default() -> PriceSummary
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for PriceSummary
impl<'de> Deserialize<'de> for PriceSummary
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for PriceSummary
impl JsonSchema for PriceSummary
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for PriceSummary
impl RefUnwindSafe for PriceSummary
impl Send for PriceSummary
impl Sync for PriceSummary
impl Unpin for PriceSummary
impl UnsafeUnpin for PriceSummary
impl UnwindSafe for PriceSummary