pub struct StoreSearchView {
pub total_hits: u64,
pub results: Vec<StoreView>,
}Fields
total_hits: u64results: Vec<StoreView>Trait Implementations
Sourceimpl Clone for StoreSearchView
impl Clone for StoreSearchView
Sourcefn clone(&self) -> StoreSearchView
fn clone(&self) -> StoreSearchView
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StoreSearchView
impl Debug for StoreSearchView
Sourceimpl From<StoreSearchResponse> for StoreSearchView
impl From<StoreSearchResponse> for StoreSearchView
Sourcefn from(r: StoreSearchResponse) -> Self
fn from(r: StoreSearchResponse) -> Self
Converts to this type from the input type.
Sourceimpl JsonSchema for StoreSearchView
impl JsonSchema for StoreSearchView
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for StoreSearchView
impl RefUnwindSafe for StoreSearchView
impl Send for StoreSearchView
impl Sync for StoreSearchView
impl Unpin for StoreSearchView
impl UnsafeUnpin for StoreSearchView
impl UnwindSafe for StoreSearchView