pub struct StoreView {
pub store_id: String,
pub name: String,
pub location: Option<String>,
pub chain: Option<String>,
pub is_web_store: bool,
pub has_pickup: bool,
pub has_home_delivery: bool,
}Fields
store_id: StringPass this as store_id to every other tool.
name: Stringlocation: Option<String>chain: Option<String>is_web_store: boolfalse means this store has no online cart, so the other tools cannot use it.
has_pickup: boolhas_home_delivery: boolTrait Implementations
Sourceimpl JsonSchema for StoreView
impl JsonSchema for StoreView
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for StoreView
impl RefUnwindSafe for StoreView
impl Send for StoreView
impl Sync for StoreView
impl Unpin for StoreView
impl UnsafeUnpin for StoreView
impl UnwindSafe for StoreView